SMS_SHINE_COUNTER = 0x80578A5b
SMS_BLUECOIN_COUNTER = 0x80578a5f
SMS_LIVES_COUNTER = 0x80578A07

SMS_SHINE_LOCATION_OFFSET = 0x80578988
SMS_SHINE_BYTE_COUNT = 15
SMS_BLUECOIN_LOCATION_OFFSET = 0x80578997
SMS_BLUECOIN_BYTE_COUNT = 55 # Should be 30 bytes, but the RAM takes up space for useless Blue Coins in memory

NOZZLE_BOXES_FLAGS_OFFSET = 0x805789F4
NOZZLE_BOXES_BYTE_COUNT = 3
DELFINO_YOSHI_UNLOCK = 0x805789F9

SMS_UNKNOWN_THING = 0x81006D57

SMS_SPRAY_NOZZLE_VALUE = "3BE00000"
SMS_HOVER_NOZZLE_VALUE = "3BE00004"
SMS_ROCKET_NOZZLE_VALUE = "3BE00001"
SMS_TURBO_NOZZLE_VALUE = "3BE00005"
SMS_NOZZLE_RELEASE = "8BFE1C85"

SMS_ROCKET_UNLOCK = 0x8029443C
SMS_ROCKET_UNLOCK_VALUE = "38600001"

SMS_TURBO_UNLOCK = 0x80294440
SMS_TURBO_UNLOCK_VALUE = "4E800020"

NEW_NOZZLE_UNLOCK = 0x805789f4
NEW_ROCKET_VALUE = "41555500"
NEW_TURBO_VALUE = "80AAAA00"
NEW_TOTAL_VALUE = "c3ffff00"

SMS_SPECIAL_FLAG = 0x80600040

SMS_NOKI_REQ = 0x802b79e3
SMS_NOKI_HI = 0x14
SMS_NOKI_LO = 0x00

SMS_CURRENT_STAGE = 0x803e970e
SMS_CURRENT_EPISODE = 0x803e970f

SMS_NEXT_STAGE = 0x803e9712
SMS_NEXT_EPISODE = 0x803e9713

# Move elsewhere maybe
ARB_NOZZLES_ENABLER = 0x80417A01
ARB_FLUDD_ENABLER = 0x80417A00
ARB_VERSION_CHECKER = 0x80578AA4
